X-Git-Url: http://git.vanrenterghem.biz/git.ikiwiki.info.git/blobdiff_plain/3697a684df0f9bf931fafb3cd7766753b47c1970..979dda9a94ec0665c7edd7e0ae35731ffca9ebdc:/IkiWiki/Plugin/websetup.pm

diff --git a/IkiWiki/Plugin/websetup.pm b/IkiWiki/Plugin/websetup.pm
index 6a5190301..0a3d90aec 100644
--- a/IkiWiki/Plugin/websetup.pm
+++ b/IkiWiki/Plugin/websetup.pm
@@ -447,10 +447,10 @@ sub showform ($$) {
 			IkiWiki::saveindex();
 			IkiWiki::unlockwiki();
 
 			# Print the top part of a standard misctemplate,
 			# then show the rebuild or refresh, live.
 			my $divider="\0";
-			my $html=IkiWiki::misctemplate("setup", $divider);
+			my $html=IkiWiki::cgitemplate($cgi, "setup", $divider);
 			IkiWiki::printheader($session);
 			my ($head, $tail)=split($divider, $html, 2);
 			print $head."<pre>\n";
@@ -447,10 +447,10 @@ sub showform ($$) {
 			IkiWiki::unlockwiki();
 
-			# Print the top part of a standard misctemplate,
+			# Print the top part of a standard cgitemplate,
 			# then show the rebuild or refresh, live.
 			my $divider="\0";